@@ -106,7 +106,7 @@ copy_logs() {
 
     # Bifrost: grab config files and logs from the container.
     if [[ $(docker ps -q -f name=bifrost_deploy) ]]; then
-        for service in dnsmasq ironic-api ironic-conductor ironic-inspector mariadb nginx rabbitmq-server; do
+        for service in dnsmasq ironic ironic-inspector mariadb nginx; do
             mkdir -p ${LOG_DIR}/kolla/$service
             docker exec bifrost_deploy \
                 systemctl status $service -l -n 10000 > ${LOG_DIR}/kolla/$service/${service}-systemd-status.txt
